@@ -15,10 +15,13 @@ import shutil as __shutil
 import ast as __ast
 import json as __json
 import sys as __sys
-import readline as __readline
+try:
+    import readline as __readline
+    __readline.parse_and_bind('tab: complete')
+except:
+    pass
 from time import sleep as __sleep
 
-__readline.parse_and_bind('tab: complete')
 
 # try:
 #     from pip import main as pipmain
@@ -59,6 +62,8 @@ __workers__ = []
 __telegrambot_name__ = 'ht-bot'
 __telegrambot_token__ = ''
 
+__is_all_loaded__ = False
+
 def __checkLibraryUpdate__():
     try:
         # Check Version Update
@@ -124,6 +129,9 @@ def getModule(moduleName):
     while any( [ work.startswith('import-module-') for work in getWorkers() ] ):
         __sleep(0.1)
 
+    while not __is_all_loaded__:
+        __sleep(0.1)
+
     for m in __modules_loaded__:
         if moduleName in m:
             if not 'ht_' in moduleName:
@@ -585,6 +593,7 @@ def __importModules__():
                 except Exception as e:
                     Logger.printMessage(message='__importModules__', description='{moduleName} File not found: {error}'.format(moduleName=files, error=str(e)), is_error=True)
                     pass
+    __is_all_loaded__ = True
 
 worker('check-library-updated', 'ht.__checkLibraryUpdate__', loop=False, run_until_ht_stops=True, log=__amidjango__)
 worker('refresh-pool-servers', 'ht.Pool.__checkPoolNodes__', timesleep=180, run_until_ht_stops=True, log=__amidjango__)
